==> petsc-3.20.2_0%2Baccelerate%2Bhwloc%2Bmpich.darwin_19.x86_64.tbz2: opt/local/lib/petsc/include/petscconf_poison.h <==
#pragma GCC poison PETSC_PETSC_HAVE_ACCESS
#pragma GCC poison PETSC_PETSC_HAVE_ATOLL
#pragma GCC poison PETSC_PETSC_HAVE_ATTRIBUTEALIGNED
#pragma GCC poison PETSC_PETSC_HAVE_BUILTIN_EXPECT
#pragma GCC poison PETSC_PETSC_HAVE_BZERO
#pragma GCC poison PETSC_PETSC_HAVE_C99_COMPLEX
#pragma GCC poison PETSC_PETSC_HAVE_CLOCK
#pragma GCC poison PETSC_PETSC_HAVE_CXX
#pragma GCC poison PETSC_PETSC_HAVE_CXXABI_H
#pragma GCC poison PETSC_PETSC_HAVE_CXX_ATOMIC
#pragma GCC poison PETSC_PETSC_HAVE_CXX_COMPLEX
#pragma GCC poison PETSC_PETSC_HAVE_CXX_COMPLEX_FIX
#pragma GCC poison PETSC_PETSC_HAVE_CXX_DIALECT_CXX11
#pragma GCC poison PETSC_PETSC_HAVE_CXX_DIALECT_CXX14
#pragma GCC poison PETSC_PETSC_HAVE_CXX_DIALECT_CXX17
#pragma GCC poison PETSC_PETSC_HAVE_DLADDR
#pragma GCC poison PETSC_PETSC_HAVE_DLCLOSE
#pragma GCC poison PETSC_PETSC_HAVE_DLERROR
#pragma GCC poison PETSC_PETSC_HAVE_DLFCN_H
#pragma GCC poison PETSC_PETSC_HAVE_DLOPEN
#pragma GCC poison PETSC_PETSC_HAVE_DLSYM
#pragma GCC poison PETSC_PETSC_HAVE_DOUBLE_ALIGN_MALLOC
#pragma GCC poison PETSC_PETSC_HAVE_DRAND48
#pragma GCC poison PETSC_PETSC_HAVE_DYNAMIC_LIBRARIES
#pragma GCC poison PETSC_PETSC_HAVE_ERF
#pragma GCC poison PETSC_PETSC_HAVE_EXECUTABLE_EXPORT
#pragma GCC poison PETSC_PETSC_HAVE_FCNTL_H
#pragma GCC poison PETSC_PETSC_HAVE_FENV_H
#pragma GCC poison PETSC_PETSC_HAVE_FE_VALUES
#pragma GCC poison PETSC_PETSC_HAVE_FLOAT_H
#pragma GCC poison PETSC_PETSC_HAVE_FORK
#pragma GCC poison PETSC_PETSC_HAVE_FORTRAN_FLUSH
#pragma GCC poison PETSC_PETSC_HAVE_FORTRAN_GET_COMMAND_ARGUMENT
#pragma GCC poison PETSC_PETSC_HAVE_FORTRAN_TYPE_STAR
#pragma GCC poison PETSC_PETSC_HAVE_FORTRAN_UNDERSCORE
#pragma GCC poison PETSC_PETSC_HAVE_GETCWD
#pragma GCC poison PETSC_PETSC_HAVE_GETDOMAINNAME
#pragma GCC poison PETSC_PETSC_HAVE_GETHOSTBYNAME
#pragma GCC poison PETSC_PETSC_HAVE_GETHOSTNAME
#pragma GCC poison PETSC_PETSC_HAVE_GETPAGESIZE
#pragma GCC poison PETSC_PETSC_HAVE_GETRUSAGE
#pragma GCC poison PETSC_PETSC_HAVE_HWLOC
#pragma GCC poison PETSC_PETSC_HAVE_IMMINTRIN_H
#pragma GCC poison PETSC_PETSC_HAVE_INTTYPES_H
#pragma GCC poison PETSC_PETSC_HAVE_ISINF
#pragma GCC poison PETSC_PETSC_HAVE_ISNAN
#pragma GCC poison PETSC_PETSC_HAVE_ISNORMAL
#pragma GCC poison PETSC_PETSC_HAVE_LGAMMA
#pragma GCC poison PETSC_PETSC_HAVE_LOG2
#pragma GCC poison PETSC_PETSC_HAVE_LSEEK
#pragma GCC poison PETSC_PETSC_HAVE_MACHINE_ENDIAN_H
#pragma GCC poison PETSC_PETSC_HAVE_MEMMOVE
#pragma GCC poison PETSC_PETSC_HAVE_MKSTEMP
#pragma GCC poison PETSC_PETSC_HAVE_MMAP
#pragma GCC poison PETSC_PETSC_HAVE_MPICH_NUMVERSION
#pragma GCC poison PETSC_PETSC_HAVE_MPIEXEC_ENVIRONMENTAL_VARIABLE
#pragma GCC poison PETSC_PETSC_HAVE_MPIIO
#pragma GCC poison PETSC_PETSC_HAVE_MPI_COMBINER_CONTIGUOUS
#pragma GCC poison PETSC_PETSC_HAVE_MPI_COMBINER_DUP
#pragma GCC poison PETSC_PETSC_HAVE_MPI_COMBINER_NAMED
#pragma GCC poison PETSC_PETSC_HAVE_MPI_F90MODULE
#pragma GCC poison PETSC_PETSC_HAVE_MPI_F90MODULE_VISIBILITY
#pragma GCC poison PETSC_PETSC_HAVE_MPI_FEATURE_DYNAMIC_WINDOW
#pragma GCC poison PETSC_PETSC_HAVE_MPI_GET_ACCUMULATE
#pragma GCC poison PETSC_PETSC_HAVE_MPI_GET_LIBRARY_VERSION
#pragma GCC poison PETSC_PETSC_HAVE_MPI_INIT_THREAD
#pragma GCC poison PETSC_PETSC_HAVE_MPI_INT64_T
#pragma GCC poison PETSC_PETSC_HAVE_MPI_LARGE_COUNT
#pragma GCC poison PETSC_PETSC_HAVE_MPI_LONG_DOUBLE
#pragma GCC poison PETSC_PETSC_HAVE_MPI_NEIGHBORHOOD_COLLECTIVES
#pragma GCC poison PETSC_PETSC_HAVE_MPI_NONBLOCKING_COLLECTIVES
#pragma GCC poison PETSC_PETSC_HAVE_MPI_ONE_SIDED
#pragma GCC poison PETSC_PETSC_HAVE_MPI_PROCESS_SHARED_MEMORY
#pragma GCC poison PETSC_PETSC_HAVE_MPI_REDUCE_LOCAL
#pragma GCC poison PETSC_PETSC_HAVE_MPI_REDUCE_SCATTER_BLOCK
#pragma GCC poison PETSC_PETSC_HAVE_MPI_RGET
#pragma GCC poison PETSC_PETSC_HAVE_MPI_WIN_CREATE
#pragma GCC poison PETSC_PETSC_HAVE_NANOSLEEP
#pragma GCC poison PETSC_PETSC_HAVE_NETDB_H
#pragma GCC poison PETSC_PETSC_HAVE_NETINET_IN_H
#pragma GCC poison PETSC_PETSC_HAVE_PACKAGES
#pragma GCC poison PETSC_PETSC_HAVE_POPEN
#pragma GCC poison PETSC_PETSC_HAVE_POSIX_MEMALIGN
#pragma GCC poison PETSC_PETSC_HAVE_PTHREAD
#pragma GCC poison PETSC_PETSC_HAVE_PWD_H
#pragma GCC poison PETSC_PETSC_HAVE_RAND
#pragma GCC poison PETSC_PETSC_HAVE_READLINK
#pragma GCC poison PETSC_PETSC_HAVE_REALPATH
#pragma GCC poison PETSC_PETSC_HAVE_REGEX
#pragma GCC poison PETSC_PETSC_HAVE_RTLD_DEFAULT
#pragma GCC poison PETSC_PETSC_HAVE_RTLD_GLOBAL
#pragma GCC poison PETSC_PETSC_HAVE_RTLD_LAZY
#pragma GCC poison PETSC_PETSC_HAVE_RTLD_LOCAL
#pragma GCC poison PETSC_PETSC_HAVE_RTLD_NOW
#pragma GCC poison PETSC_PETSC_HAVE_SETJMP_H
#pragma GCC poison PETSC_PETSC_HAVE_SLEEP
#pragma GCC poison PETSC_PETSC_HAVE_SNPRINTF
#pragma GCC poison PETSC_PETSC_HAVE_SOCKET
#pragma GCC poison PETSC_PETSC_HAVE_SO_REUSEADDR
#pragma GCC poison PETSC_PETSC_HAVE_STDATOMIC_H
#pragma GCC poison PETSC_PETSC_HAVE_STDINT_H
#pragma GCC poison PETSC_PETSC_HAVE_STRCASECMP
#pragma GCC poison PETSC_PETSC_HAVE_STRINGS_H
#pragma GCC poison PETSC_PETSC_HAVE_STRUCT_SIGACTION
#pragma GCC poison PETSC_PETSC_HAVE_SYS_PARAM_H
#pragma GCC poison PETSC_PETSC_HAVE_SYS_RESOURCE_H
#pragma GCC poison PETSC_PETSC_HAVE_SYS_SOCKET_H
#pragma GCC poison PETSC_PETSC_HAVE_SYS_TIMES_H
#pragma GCC poison PETSC_PETSC_HAVE_SYS_TIME_H
#pragma GCC poison PETSC_PETSC_HAVE_SYS_TYPES_H
#pragma GCC poison PETSC_PETSC_HAVE_SYS_UTSNAME_H
#pragma GCC poison PETSC_PETSC_HAVE_SYS_WAIT_H
#pragma GCC poison PETSC_PETSC_HAVE_TAU_PERFSTUBS
#pragma GCC poison PETSC_PETSC_HAVE_TGAMMA
#pragma GCC poison PETSC_PETSC_HAVE_TIME
#pragma GCC poison PETSC_PETSC_HAVE_TIME_H
#pragma GCC poison PETSC_PETSC_HAVE_UNAME
#pragma GCC poison PETSC_PETSC_HAVE_UNISTD_H
#pragma GCC poison PETSC_PETSC_HAVE_USLEEP
#pragma GCC poison PETSC_PETSC_HAVE_VA_COPY
#pragma GCC poison PETSC_PETSC_HAVE_VSNPRINTF
#pragma GCC poison PETSC_PETSC_HAVE_XMMINTRIN_H
#pragma GCC poison PETSC_PETSC_USE_AVX512_KERNELS
#pragma GCC poison PETSC_PETSC_USE_BACKWARD_LOOP
#pragma GCC poison PETSC_PETSC_USE_CTABLE
#pragma GCC poison PETSC_PETSC_USE_DEBUGGER
#pragma GCC poison PETSC_PETSC_USE_DMLANDAU_2D
#pragma GCC poison PETSC_PETSC_USE_FORTRAN_BINDINGS
#pragma GCC poison PETSC_PETSC_USE_INFO
#pragma GCC poison PETSC_PETSC_USE_ISATTY
#pragma GCC poison PETSC_PETSC_USE_LOG
#pragma GCC poison PETSC_PETSC_USE_MALLOC_COALESCED
#pragma GCC poison PETSC_PETSC_USE_REAL_DOUBLE
#pragma GCC poison PETSC_PETSC_USE_SHARED_LIBRARIES
#pragma GCC poison PETSC_PETSC_USE_SINGLE_LIBRARY
#pragma GCC poison PETSC_PETSC_USE_SOCKET_VIEWER
#pragma GCC poison PETSC_PETSC_USE_VISIBILITY_C
#pragma GCC poison PETSC_PETSC_USE_VISIBILITY_CXX

==> petsc-3.22.1_0%2Baccelerate%2Bhwloc%2Bmpich.darwin_19.x86_64.tbz2: opt/local/lib/petsc/include/petscconf_poison.h <==
#pragma GCC poison PETSC_PETSC_HAVE_ACCESS
#pragma GCC poison PETSC_PETSC_HAVE_APPLE_ACCELERATE
#pragma GCC poison PETSC_PETSC_HAVE_ATOLL
#pragma GCC poison PETSC_PETSC_HAVE_ATTRIBUTEALIGNED
#pragma GCC poison PETSC_PETSC_HAVE_BUILTIN_EXPECT
#pragma GCC poison PETSC_PETSC_HAVE_BZERO
#pragma GCC poison PETSC_PETSC_HAVE_C99_COMPLEX
#pragma GCC poison PETSC_PETSC_HAVE_CLOCK
#pragma GCC poison PETSC_PETSC_HAVE_CXX
#pragma GCC poison PETSC_PETSC_HAVE_CXXABI_H
#pragma GCC poison PETSC_PETSC_HAVE_CXX_ATOMIC
#pragma GCC poison PETSC_PETSC_HAVE_CXX_COMPLEX
#pragma GCC poison PETSC_PETSC_HAVE_CXX_COMPLEX_FIX
#pragma GCC poison PETSC_PETSC_HAVE_CXX_DIALECT_CXX11
#pragma GCC poison PETSC_PETSC_HAVE_CXX_DIALECT_CXX14
#pragma GCC poison PETSC_PETSC_HAVE_CXX_DIALECT_CXX17
#pragma GCC poison PETSC_PETSC_HAVE_DLADDR
#pragma GCC poison PETSC_PETSC_HAVE_DLCLOSE
#pragma GCC poison PETSC_PETSC_HAVE_DLERROR
#pragma GCC poison PETSC_PETSC_HAVE_DLFCN_H
#pragma GCC poison PETSC_PETSC_HAVE_DLOPEN
#pragma GCC poison PETSC_PETSC_HAVE_DLSYM
#pragma GCC poison PETSC_PETSC_HAVE_DOUBLE_ALIGN_MALLOC
#pragma GCC poison PETSC_PETSC_HAVE_DRAND48
#pragma GCC poison PETSC_PETSC_HAVE_DYNAMIC_LIBRARIES
#pragma GCC poison PETSC_PETSC_HAVE_ERF
#pragma GCC poison PETSC_PETSC_HAVE_EXECUTABLE_EXPORT
#pragma GCC poison PETSC_PETSC_HAVE_FCNTL_H
#pragma GCC poison PETSC_PETSC_HAVE_FENV_H
#pragma GCC poison PETSC_PETSC_HAVE_FE_VALUES
#pragma GCC poison PETSC_PETSC_HAVE_FLOAT_H
#pragma GCC poison PETSC_PETSC_HAVE_FORK
#pragma GCC poison PETSC_PETSC_HAVE_FORTRAN_FLUSH
#pragma GCC poison PETSC_PETSC_HAVE_FORTRAN_FREE_LINE_LENGTH_NONE
#pragma GCC poison PETSC_PETSC_HAVE_FORTRAN_TYPE_STAR
#pragma GCC poison PETSC_PETSC_HAVE_FORTRAN_UNDERSCORE
#pragma GCC poison PETSC_PETSC_HAVE_GETCWD
#pragma GCC poison PETSC_PETSC_HAVE_GETDOMAINNAME
#pragma GCC poison PETSC_PETSC_HAVE_GETHOSTBYNAME
#pragma GCC poison PETSC_PETSC_HAVE_GETHOSTNAME
#pragma GCC poison PETSC_PETSC_HAVE_GETPAGESIZE
#pragma GCC poison PETSC_PETSC_HAVE_GETRUSAGE
#pragma GCC poison PETSC_PETSC_HAVE_HWLOC
#pragma GCC poison PETSC_PETSC_HAVE_IMMINTRIN_H
#pragma GCC poison PETSC_PETSC_HAVE_INTTYPES_H
#pragma GCC poison PETSC_PETSC_HAVE_ISINF
#pragma GCC poison PETSC_PETSC_HAVE_ISNAN
#pragma GCC poison PETSC_PETSC_HAVE_ISNORMAL
#pragma GCC poison PETSC_PETSC_HAVE_LGAMMA
#pragma GCC poison PETSC_PETSC_HAVE_LOG2
#pragma GCC poison PETSC_PETSC_HAVE_LSEEK
#pragma GCC poison PETSC_PETSC_HAVE_MACHINE_ENDIAN_H
#pragma GCC poison PETSC_PETSC_HAVE_MEMMOVE
#pragma GCC poison PETSC_PETSC_HAVE_MKSTEMP
#pragma GCC poison PETSC_PETSC_HAVE_MPICH
#pragma GCC poison PETSC_PETSC_HAVE_MPIEXEC_ENVIRONMENTAL_VARIABLE
#pragma GCC poison PETSC_PETSC_HAVE_MPIIO
#pragma GCC poison PETSC_PETSC_HAVE_MPIX_STREAM
#pragma GCC poison PETSC_PETSC_HAVE_MPIX_THREADCOMM
#pragma GCC poison PETSC_PETSC_HAVE_MPI_COMBINER_CONTIGUOUS
#pragma GCC poison PETSC_PETSC_HAVE_MPI_COMBINER_DUP
#pragma GCC poison PETSC_PETSC_HAVE_MPI_COMBINER_NAMED
#pragma GCC poison PETSC_PETSC_HAVE_MPI_COUNT
#pragma GCC poison PETSC_PETSC_HAVE_MPI_F90MODULE
#pragma GCC poison PETSC_PETSC_HAVE_MPI_F90MODULE_VISIBILITY
#pragma GCC poison PETSC_PETSC_HAVE_MPI_FEATURE_DYNAMIC_WINDOW
#pragma GCC poison PETSC_PETSC_HAVE_MPI_GET_ACCUMULATE
#pragma GCC poison PETSC_PETSC_HAVE_MPI_GET_LIBRARY_VERSION
#pragma GCC poison PETSC_PETSC_HAVE_MPI_INIT_THREAD
#pragma GCC poison PETSC_PETSC_HAVE_MPI_INT64_T
#pragma GCC poison PETSC_PETSC_HAVE_MPI_LARGE_COUNT
#pragma GCC poison PETSC_PETSC_HAVE_MPI_LONG_DOUBLE
#pragma GCC poison PETSC_PETSC_HAVE_MPI_NEIGHBORHOOD_COLLECTIVES
#pragma GCC poison PETSC_PETSC_HAVE_MPI_NONBLOCKING_COLLECTIVES
#pragma GCC poison PETSC_PETSC_HAVE_MPI_ONE_SIDED
#pragma GCC poison PETSC_PETSC_HAVE_MPI_PERSISTENT_NEIGHBORHOOD_COLLECTIVES
#pragma GCC poison PETSC_PETSC_HAVE_MPI_PROCESS_SHARED_MEMORY
#pragma GCC poison PETSC_PETSC_HAVE_MPI_REDUCE_LOCAL
#pragma GCC poison PETSC_PETSC_HAVE_MPI_REDUCE_SCATTER_BLOCK
#pragma GCC poison PETSC_PETSC_HAVE_MPI_RGET
#pragma GCC poison PETSC_PETSC_HAVE_MPI_WIN_CREATE
#pragma GCC poison PETSC_PETSC_HAVE_NANOSLEEP
#pragma GCC poison PETSC_PETSC_HAVE_NETDB_H
#pragma GCC poison PETSC_PETSC_HAVE_NETINET_IN_H
#pragma GCC poison PETSC_PETSC_HAVE_PACKAGES
#pragma GCC poison PETSC_PETSC_HAVE_POPEN
#pragma GCC poison PETSC_PETSC_HAVE_POSIX_MEMALIGN
#pragma GCC poison PETSC_PETSC_HAVE_PTHREAD
#pragma GCC poison PETSC_PETSC_HAVE_PTHREAD_MUTEX
#pragma GCC poison PETSC_PETSC_HAVE_PWD_H
#pragma GCC poison PETSC_PETSC_HAVE_RAND
#pragma GCC poison PETSC_PETSC_HAVE_READLINK
#pragma GCC poison PETSC_PETSC_HAVE_REALPATH
#pragma GCC poison PETSC_PETSC_HAVE_REGEX
#pragma GCC poison PETSC_PETSC_HAVE_RTLD_DEFAULT
#pragma GCC poison PETSC_PETSC_HAVE_RTLD_GLOBAL
#pragma GCC poison PETSC_PETSC_HAVE_RTLD_LAZY
#pragma GCC poison PETSC_PETSC_HAVE_RTLD_LOCAL
#pragma GCC poison PETSC_PETSC_HAVE_RTLD_NOW
#pragma GCC poison PETSC_PETSC_HAVE_SETJMP_H
#pragma GCC poison PETSC_PETSC_HAVE_SHMGET
#pragma GCC poison PETSC_PETSC_HAVE_SLEEP
#pragma GCC poison PETSC_PETSC_HAVE_SNPRINTF
#pragma GCC poison PETSC_PETSC_HAVE_SOCKET
#pragma GCC poison PETSC_PETSC_HAVE_SO_REUSEADDR
#pragma GCC poison PETSC_PETSC_HAVE_STDATOMIC_H
#pragma GCC poison PETSC_PETSC_HAVE_STDINT_H
#pragma GCC poison PETSC_PETSC_HAVE_STRCASECMP
#pragma GCC poison PETSC_PETSC_HAVE_STRINGS_H
#pragma GCC poison PETSC_PETSC_HAVE_STRUCT_SIGACTION
#pragma GCC poison PETSC_PETSC_HAVE_SYS_PARAM_H
#pragma GCC poison PETSC_PETSC_HAVE_SYS_RESOURCE_H
#pragma GCC poison PETSC_PETSC_HAVE_SYS_SOCKET_H
#pragma GCC poison PETSC_PETSC_HAVE_SYS_TIMES_H
#pragma GCC poison PETSC_PETSC_HAVE_SYS_TIME_H
#pragma GCC poison PETSC_PETSC_HAVE_SYS_TYPES_H
#pragma GCC poison PETSC_PETSC_HAVE_SYS_UTSNAME_H
#pragma GCC poison PETSC_PETSC_HAVE_SYS_WAIT_H
#pragma GCC poison PETSC_PETSC_HAVE_TAU_PERFSTUBS
#pragma GCC poison PETSC_PETSC_HAVE_TGAMMA
#pragma GCC poison PETSC_PETSC_HAVE_TIME
#pragma GCC poison PETSC_PETSC_HAVE_TIME_H
#pragma GCC poison PETSC_PETSC_HAVE_UNAME
#pragma GCC poison PETSC_PETSC_HAVE_UNISTD_H
#pragma GCC poison PETSC_PETSC_HAVE_USLEEP
#pragma GCC poison PETSC_PETSC_HAVE_VA_COPY
#pragma GCC poison PETSC_PETSC_HAVE_VSNPRINTF
#pragma GCC poison PETSC_PETSC_HAVE_XMMINTRIN_H
#pragma GCC poison PETSC_PETSC_USE_AVX512_KERNELS
#pragma GCC poison PETSC_PETSC_USE_BACKWARD_LOOP
#pragma GCC poison PETSC_PETSC_USE_CTABLE
#pragma GCC poison PETSC_PETSC_USE_DEBUGGER
#pragma GCC poison PETSC_PETSC_USE_DMLANDAU_2D
#pragma GCC poison PETSC_PETSC_USE_FORTRAN_BINDINGS
#pragma GCC poison PETSC_PETSC_USE_INFO
#pragma GCC poison PETSC_PETSC_USE_ISATTY
#pragma GCC poison PETSC_PETSC_USE_LOG
#pragma GCC poison PETSC_PETSC_USE_MALLOC_COALESCED
#pragma GCC poison PETSC_PETSC_USE_REAL_DOUBLE
#pragma GCC poison PETSC_PETSC_USE_SHARED_LIBRARIES
#pragma GCC poison PETSC_PETSC_USE_SINGLE_LIBRARY
#pragma GCC poison PETSC_PETSC_USE_SOCKET_VIEWER
#pragma GCC poison PETSC_PETSC_USE_VISIBILITY_C
#pragma GCC poison PETSC_PETSC_USE_VISIBILITY_CXX
